@@ -2,9 +2,6 @@
 
 // SPDX-License-Identifier: GPL-2.0-or-later
 
-#ifndef KIG_MISC_BUILTIN_STUFF_H
-#define KIG_MISC_BUILTIN_STUFF_H
+#pragma once
 
 void setupBuiltinStuff();
-
-#endif
