@@ -23,8 +23,8 @@
  * Bézier curve of degree 2
  */
 
-static const char bezier2_constructstatement[] = I18N_NOOP("Construct a quadratic Bézier curve with this control point");
-static const char bezier2_constructstatement2[] = I18N_NOOP("Select a point to be a control point of the new quadratic Bézier curve...");
+static const KLazyLocalizedString bezier2_constructstatement = kli18n("Construct a quadratic Bézier curve with this control point");
+static const KLazyLocalizedString bezier2_constructstatement2 = kli18n("Select a point to be a control point of the new quadratic Bézier curve...");
 
 static const struct ArgsParser::spec argsspecBezier2[] = {
     // mp: the central control point is not on the curve
@@ -118,8 +118,8 @@ std::vector<ObjectCalcer *> BezierQuadricType::movableParents(const ObjectTypeCa
  * Bézier curve of degree 3
  */
 
-static const char bezier3_constructstatement[] = I18N_NOOP("Construct a cubic Bézier curve with this control point");
-static const char bezier3_constructstatement2[] = I18N_NOOP("Select a point to be a control point of the new cubic Bézier curve...");
+static const KLazyLocalizedString bezier3_constructstatement = kli18n("Construct a cubic Bézier curve with this control point");
+static const KLazyLocalizedString bezier3_constructstatement2 = kli18n("Select a point to be a control point of the new cubic Bézier curve...");
 
 static const struct ArgsParser::spec argsspecBezier3[] = {{PointImp::stype(), bezier3_constructstatement, bezier3_constructstatement2, true},
                                                           {PointImp::stype(), bezier3_constructstatement, bezier3_constructstatement2, false},
@@ -325,9 +325,9 @@ std::vector<ObjectCalcer *> BezierCurveType::movableParents(const ObjectTypeCalc
  * Rational Bézier curve of degree 2
  */
 
-static const char rbezier2_constructstatement[] = I18N_NOOP("Construct a quadratic rational Bézier curve with this control point");
-static const char rbezier2_constructstatement2[] = I18N_NOOP("Select three points and three numeric values as weights to construct rational Bézier curve...");
-static const char rbezier2_constructstatement3[] = I18N_NOOP("Select this value as weight");
+static const KLazyLocalizedString rbezier2_constructstatement = kli18n("Construct a quadratic rational Bézier curve with this control point");
+static const KLazyLocalizedString rbezier2_constructstatement2 = kli18n("Select three points and three numeric values as weights to construct rational Bézier curve...");
+static const KLazyLocalizedString rbezier2_constructstatement3 = kli18n("Select this value as weight");
 
 static const struct ArgsParser::spec argsspecRationalBezier2[] = {{PointImp::stype(), rbezier2_constructstatement, rbezier2_constructstatement2, true},
                                                                   {&weightimptypeinstance, rbezier2_constructstatement3, rbezier2_constructstatement2, false},
@@ -430,9 +430,9 @@ std::vector<ObjectCalcer *> RationalBezierQuadricType::movableParents(const Obje
  * Rational Bézier curve of degree 3
  */
 
-static const char rbezier3_constructstatement[] = I18N_NOOP("Construct a cubic rational Bézier curve with this control point");
-static const char rbezier3_constructstatement2[] = I18N_NOOP("Select three points and three numeric values as weights to construct rational Bézier curve...");
-static const char rbezier3_constructstatement3[] = I18N_NOOP("Select this value as weight");
+static const KLazyLocalizedString rbezier3_constructstatement = kli18n("Construct a cubic rational Bézier curve with this control point");
+static const KLazyLocalizedString rbezier3_constructstatement2 = kli18n("Select three points and three numeric values as weights to construct rational Bézier curve...");
+static const KLazyLocalizedString rbezier3_constructstatement3 = kli18n("Select this value as weight");
 
 static const struct ArgsParser::spec argsspecRationalBezier3[] = {{PointImp::stype(), rbezier3_constructstatement, rbezier3_constructstatement2, true},
                                                                   {&weightimptypeinstance, rbezier3_constructstatement3, rbezier3_constructstatement2, false},
