@@ -596,8 +596,8 @@ const ObjectImpType *AngleImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "angle",
                                  kli18n("angle"),
-                                 I18N_NOOP("Select this angle"),
-                                 I18N_NOOP("Select angle %1"),
+                                 kli18n("Select this angle"),
+                                 kli18n("Select angle %1"),
                                  kli18n("Remove an Angle"),
                                  kli18n("Add an Angle"),
                                  kli18n("Move an Angle"),
@@ -611,8 +611,8 @@ const ObjectImpType *VectorImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "vector",
                                  kli18n("vector"),
-                                 I18N_NOOP("Select this vector"),
-                                 I18N_NOOP("Select vector %1"),
+                                 kli18n("Select this vector"),
+                                 kli18n("Select vector %1"),
                                  kli18n("Remove a Vector"),
                                  kli18n("Add a Vector"),
                                  kli18n("Move a Vector"),
@@ -626,8 +626,8 @@ const ObjectImpType *ArcImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "arc",
                                  kli18n("arc"),
-                                 I18N_NOOP("Select this arc"),
-                                 I18N_NOOP("Select arc %1"),
+                                 kli18n("Select this arc"),
+                                 kli18n("Select arc %1"),
                                  kli18n("Remove an Arc"),
                                  kli18n("Add an Arc"),
                                  kli18n("Move an Arc"),
